@@ -1,31 +1,35 @@
+from spacy.language import Language
+from spacy.tokens import Doc
+
 from .basic_stats import BasicStats
 from .diversity_stats import DiversityStats
 from .morph_stats import MorphStats
 from .readability_stats import ReadabilityStats
-from spacy.tokens import Doc
 
+
+@Language.factory("basic")
 class BasicStatsComponent(object):
     """
     Класс для компонента основных статистик текста
 
     Примеры использования:
     Добавление компонента в пайплайн:
-        >>> from ruts import BasicStatsComponent
-        >>> nlp = spacy.load('ru')
-        >>> bsc = BasicStatsComponent()
-        >>> nlp.add_pipe(bsc, 'basic', last=True)
+        >>> import ruts
+        >>> import spacy
+        >>> nlp = spacy.load('ru_core_news_sm')
+        >>> nlp.add_pipe('basic', last=True)
 
     Доступ к извлеченным статистикам:
         >>> doc = nlp("мама мыла раму")
-        >>> doc._.bs.get_stats()
-        >>> doc._.bs.c_letters
+        >>> doc._.basic.get_stats()
+        >>> doc._.basic.c_letters
         {4: 3}
 
     Аргументы:
         name (str): Наименование компонента в пайплайне
     """
 
-    def __init__(self, name: str = "bs"):
+    def __init__(self, nlp: Language, name: str = "basic"):
         self.name = name
         Doc.set_extension(self.name, default=None, force=True)
 
@@ -43,27 +47,29 @@ class BasicStatsComponent(object):
         doc._.set(self.name, bs)
         return doc
 
+
+@Language.factory("morph")
 class MorphStatsComponent(object):
     """
     Класс для компонента морфологических статистик текста
 
     Добавление компонента в пайплайн:
-        >>> from ruts import MorphStatsComponent
-        >>> nlp = spacy.load('ru')
-        >>> msc = MorphStatsComponent()
-        >>> nlp.add_pipe(msc, 'morph', last=True)
+        >>> import ruts
+        >>> import spacy
+        >>> nlp = spacy.load('ru_core_news_sm')
+        >>> nlp.add_pipe('morph', last=True)
 
     Доступ к извлеченным статистикам:
         >>> doc = nlp("мама мыла раму")
-        >>> doc._.ms.get_stats()
-        >>> doc._.ms.case
+        >>> doc._.morph.get_stats()
+        >>> doc._.morph.case
         ('nomn', 'gent', 'datv')
 
     Аргументы:
         name (str): Наименование компонента в пайплайне
     """
 
-    def __init__(self, name: str = "ms"):
+    def __init__(self, nlp: Language, name: str = "morph"):
         self.name = name
         Doc.set_extension(self.name, default=None, force=True)
 
@@ -81,27 +87,29 @@ class MorphStatsComponent(object):
         doc._.set(self.name, ms)
         return doc
 
+
+@Language.factory("readability")
 class ReadabilityStatsComponent(object):
     """
     Класс для компонента основных метрик удобочитаемости текста
 
     Добавление компонента в пайплайн:
-        >>> from ruts import ReadabilityStatsComponent
-        >>> nlp = spacy.load('ru')
-        >>> rsc = ReadabilityStatsComponent()
-        >>> nlp.add_pipe(rsc, 'readability', last=True)
+        >>> import ruts
+        >>> import spacy
+        >>> nlp = spacy.load('ru_core_news_sm')
+        >>> nlp.add_pipe('readability', last=True)
 
     Доступ к извлеченным метрикам:
         >>> doc = nlp("мама мыла раму")
-        >>> doc._.rs.get_stats()
-        >>> doc._.rs.flesch_reading_easy
+        >>> doc._.readability.get_stats()
+        >>> doc._.readability.flesch_reading_easy
         82.735
 
     Аргументы:
         name (str): Наименование компонента в пайплайне
     """
 
-    def __init__(self, name: str = "rs"):
+    def __init__(self, nlp: Language, name: str = "readability"):
         self.name = name
         Doc.set_extension(self.name, default=None, force=True)
 
@@ -119,27 +127,29 @@ class ReadabilityStatsComponent(object):
         doc._.set(self.name, rs)
         return doc
 
+
+@Language.factory("diversity")
 class DiversityStatsComponent(object):
     """
     Класс для компонента основных метрик лексического разнообразия текста
 
     Добавление компонента в пайплайн:
-        >>> from ruts import DiversityStatsComponent
-        >>> nlp = spacy.load('ru')
-        >>> dsc = DiversityStatsComponent()
-        >>> nlp.add_pipe(dsc, 'diversity', last=True)
+        >>> import ruts
+        >>> import spacy
+        >>> nlp = spacy.load('ru_core_news_sm')
+        >>> nlp.add_pipe('diversity', last=True)
 
     Доступ к извлеченным метрикам:
         >>> doc = nlp("мама мыла раму")
-        >>> doc._.ds.get_stats()
-        >>> doc._.ds.rttr
+        >>> doc._.diversity.get_stats()
+        >>> doc._.diversity.rttr
         1.7320508075688774
 
     Аргументы:
         name (str): Наименование компонента в пайплайне
     """
 
-    def __init__(self, name: str = "ds"):
+    def __init__(self, nlp: Language, name: str = "diversity"):
         self.name = name
         Doc.set_extension(self.name, default=None, force=True)
 
@@ -155,4 +165,4 @@ class DiversityStatsComponent(object):
         """
         ds = DiversityStats(doc)
         doc._.set(self.name, ds)
-        return doc
\ No newline at end of file
+        return doc
